TryStream

Trait TryStream 

pub trait TryStream: Stream<Item = Result<Self::Ok, Self::Err>> + Sealed {
    type Ok;
    type Err;
}
A convenience for streams that return Result values that includes a variety of adapters tailored to such futures.

This is futures::TryStream except it’s stricter on the stream super-trait.

Required Associated Types

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, E, S> TryStream for S
where S: Stream<Item = Result<T, E>> + ?Sized,

Source

type Ok = T

Source

type Err = E