Async rust task spawning and utilities that work natively (using tokio) and in browsers (using wasm-bindgen-futures).
Structs
- Abort
OnDrop Handle - A wrapper around a
tokio::task::JoinHandle, which aborts the task when it is dropped. - Join
Error - Task failed to execute to completion.
- Join
Handle - An owned permission to join on a task (await its termination).
- JoinSet
- A collection of tasks spawned on a Tokio runtime.
Functions
- spawn
- Spawns a new asynchronous task, returning a
JoinHandlefor it.