Module time

Sleep and timeout utilities that work natively (via tokio) and in the browser.

Structs

Duration
A Duration type to represent a span of time, typically used for system timeouts.
Elapsed
Errors returned by Timeout.
Instant
A measurement of a monotonically nondecreasing clock. Opaque and useful only with Duration.
Interval
Interval returned by interval and interval_at.
Sleep
Future returned by sleep and sleep_until.
SystemTime
A measurement of the system clock, useful for talking to external entities like the file system or other processes.
Timeout
Future returned by timeout and timeout_at.

Enums

MissedTickBehavior
Defines the behavior of an Interval when it misses a tick.

Functions

interval
Creates new Interval that yields with interval of period. The first tick completes immediately. The default MissedTickBehavior is Burst, but this can be configured by calling set_missed_tick_behavior.
interval_at
Creates new Interval that yields with interval of period with the first tick completing at start. The default MissedTickBehavior is Burst, but this can be configured by calling set_missed_tick_behavior.
sleep
Waits until duration has elapsed.
sleep_until
Waits until deadline is reached.
timeout
Requires a Future to complete before the specified duration has elapsed.